=======
Credits
=======

Development Lead
----------------

* GoTLiuM InSPiRiT (`gotlium <https://github.com/gotlium>`_)

Contributors
------------

* Sergey Nikitin (`nikitinsm <https://github.com/nikitinsm>`_)
* Volodymyr Tartynskyi (`vosi <https://github.com/vosi>`_)
* Petr Zelenin (`petrikoz <https://github.com/petrikoz>`_)
* icegreg (`icegreg <https://github.com/icegreg>`_)
* Andrei (`aloskutov-ki11 <https://github.com/aloskutov-ki11>`_)
* Sergey Khaylov (`skhaylov <https://github.com/skhaylov>`_)
* Ilya Streltsov (`ilstreltsov <https://github.com/ilstreltsov>`_)
* Antoine Nguyen  (`tonioo <https://github.com/tonioo>`_)
* Tomáš Peterka (`katomaso <https://github.com/katomaso>`_)
